/**
 * (c) Atos IT Solutions and Services GmbH, 2011.
 * Licensed under EUPL 1.1
 */

package com.sag.osami.api.context;

/**
 * This interface allows querying context events from the ContextStore database. The query syntax depends on the actual storage implementation of the
 * ContextStore. Up to now two implementations are shipped: a JDBC-based and an Android/SQLite-based. Hence, queries are to be supplied in SQL (refer to
 * official documentation of the used database).
 * <p>
 * For details regarding the table structure etc., see the actual storage implementation class (e.g. {@link com.sag.osami.contextstore.storage.impl.JDBCStorage}
 * or {@link com.sag.osami.contextstore.storage.impl.AndroidStorage}).
 * <p>
 * <i>OSGi notice:</i> In OSGi environments, the ContextStore is registered as a service for this interface.
 */
public interface IContextQuery {

	/**
	 * This method allows you to perform a query on the ContextStore database to get contexts with the specified properties
	 * 
	 * @param query
	 *            the query to be executed
	 * @param params
	 *            parameters which may occur in the query (e.g., using the ? syntax) and are bound accordingly (so escaping, quoting etc. is unnecessary)
	 * @return an array of {@code IContextEvent[]}s (which is empty if no contexts were found)
	 */
	ContextEvent[] query(String query, Object... params);

	/**
	 * Lazy variant of {@link #query(String, Object...)}, i.e. it loads one ContextEvent at a time during iteration. This operation is optional.
	 * 
	 * @throws UnsupportedOperationException
	 *             if the underlying storage implementation does not support lazy querying
	 * @see #query(String, Object...)
	 */
	Iterable<ContextEvent> queryLazy(String query, Object... params) throws UnsupportedOperationException;
}
