/**
 * (c) Atos IT Solutions and Services GmbH, 2011.
 * Licensed under EUPL 1.1
 */
package com.sag.osami.contextstore.serialization;

import java.util.Date;

import com.sag.osami.api.context.IContextStore;

/**
 * This extending ContextStore interface provides a method for injecting a context event which has its payload in serialized form, which is likely to be an
 * "external" event.
 */
public interface ISerializedContextReceiver extends IContextStore {

	/**
	 * Creates a new context event with given parameters.
	 * 
	 * @param originID
	 *            the origin ID
	 * @param type
	 *            see context type
	 * @param data
	 *            the serialized form of the payload
	 * @param date
	 *            see context timestamp
	 * @param contextStoreOriginID
	 *            the original context store name
	 */
	void newContextEvent(String originID, String type, String[] data, Date date, String contextStoreOriginID);

	/**
	 * Creates a new context event with given parameters
	 * 
	 * @param originID
	 *            the origin ID
	 * @param type
	 *            see context type
	 * @param data
	 *            the serialized form of the payload
	 * @param date
	 *            see context timestamp
	 * @param contextStoreOriginID
	 *            the original context store name
	 * @param persist
	 *            indicates whether context event should be persisted or not
	 */
	void newContextEvent(String originID, String type, String[] data, Date date, String contextStoreOriginID, boolean persist);
}
