/**
 * (c) Atos IT Solutions and Services GmbH, 2011.
 * Licensed under EUPL 1.1
 */
package com.sag.osami.contextstore.storage.jdbc;

import java.io.File;

import com.sag.osami.contextstore.storage.impl.JDBCStorage;

/**
 * A JDBC dialect for Derby. It also provides a reasonable default JDBC URL.
 * 
 * @see JDBCStorage
 * @see #DEFAULT_URL
 */
public class DerbyDialect extends GenericJDBCDialect {

	private static final File DEFAULT_DB_PATH;
	static {
		if (System.getProperty("os.name").startsWith("Windows"))
			DEFAULT_DB_PATH = new File(System.getenv("APPDATA"), "ContextStore");
		else
			DEFAULT_DB_PATH = new File(System.getProperty("user.home"), ".ContextStore");
	}

	/**
	 * Default URL for the Derby database.
	 * <p>
	 * On Unix-like systems, the database will be stored in <code>~/.ContextStore</code>.
	 * <p>
	 * On Windows systems, the database will be stored in <code>%APPDATA%/ContextStore</code>.
	 */
	public static final String DEFAULT_URL = String.format("jdbc:derby:%s;create=true;user=osami;password=osami", DEFAULT_DB_PATH);

	private static final String DRIVER = "org.apache.derby.jdbc.EmbeddedDriver";

	@Override
	public String driver() {
		return DRIVER;
	}

	private static final String[] COL_TYPES = { "BIGINT PRIMARY KEY", "VARCHAR(255)", "VARCHAR(255)", "VARCHAR(255)", "CLOB", "VARCHAR(255)", "TIMESTAMP" };

	@Override
	public String createTable() {
		return createTable(COL_TYPES);
	}
}